==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/RingDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RingSeriesBaseDescriptionMetadata } from "./RingSeriesBaseDescriptionMetadata";
import { RingDescription } from "./RingDescription";
/**
 * @hidden
 */
var RingDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RingDescriptionMetadata, _super);
    function RingDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RingDescriptionMetadata.b = function (a) {
        if (RingDescriptionMetadata.a == null) {
            RingDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RingDescriptionMetadata.c(RingDescriptionMetadata.a);
        }
        if (a.g(RingDescriptionMetadata.a)) {
            return;
        }
        a.s(RingDescriptionMetadata.a);
        RingSeriesBaseDescriptionMetadata.d(a);
    };
    RingDescriptionMetadata.c = function (a) {
        a.item("Index", "Number:int");
        a.item("InnerExtend", "Number:double");
        a.item("ControlSize", "Size");
        a.item("Center", "Point");
        a.item("RingSeries", "ExportedType:RingSeriesBase");
        a.item("RingBreadth", "Number:double");
    };
    RingDescriptionMetadata.d = function (a) {
        RingDescriptionMetadata.b(a);
        a.u("Ring", function () { return new RingDescription(); });
        a.t("Ring", RingDescriptionMetadata.a);
    };
    RingDescriptionMetadata.$t = markType(RingDescriptionMetadata, 'RingDescriptionMetadata');
    RingDescriptionMetadata.a = null;
    return RingDescriptionMetadata;
}(Base));
export { RingDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/RingDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RingSeriesBaseDescriptionMetadata } from "./RingSeriesBaseDescriptionMetadata";
import { RingDescription } from "./RingDescription";
/**
 * @hidden
 */
var RingDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RingDescriptionMetadata, _super);
    function RingDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RingDescriptionMetadata.b = function (a) {
        if (RingDescriptionMetadata.a == null) {
            RingDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RingDescriptionMetadata.c(RingDescriptionMetadata.a);
        }
        if (a.j(RingDescriptionMetadata.a)) {
            return;
        }
        a.y(RingDescriptionMetadata.a);
        RingSeriesBaseDescriptionMetadata.d(a);
    };
    RingDescriptionMetadata.c = function (a) {
        a.item("Index", "Number:int");
        a.item("InnerExtend", "Number:double");
        a.item("ControlSize", "Size");
        a.item("Center", "Point");
        a.item("RingSeries", "ExportedType:RingSeriesBase");
        a.item("RingBreadth", "Number:double");
    };
    RingDescriptionMetadata.d = function (a) {
        RingDescriptionMetadata.b(a);
        a.aa("Ring", function () { return new RingDescription(); });
        a.z("Ring", RingDescriptionMetadata.a);
    };
    RingDescriptionMetadata.$t = markType(RingDescriptionMetadata, 'RingDescriptionMetadata');
    RingDescriptionMetadata.a = null;
    return RingDescriptionMetadata;
}(Base));
export { RingDescriptionMetadata };
